@@ -1,5 +1,7 @@
 import locale
+import math
 import os
+import traceback
 from collections import defaultdict
 from datetime import datetime
 
@@ -8,8 +10,10 @@ from PyQt5.QtCore import pyqtSlot, QTimer, Qt, pyqtSignal, QItemSelection, QItem
     QModelIndex
 from PyQt5.QtGui import QContextMenuEvent, QIcon
 from PyQt5.QtWidgets import QMessageBox, QAbstractItemView, QUndoStack, QMenu, QWidget, QHeaderView
+from urh.util.Errors import Errors
 
 from urh import constants
+from urh.awre import AutoAssigner
 from urh.controller.dialogs.MessageTypeDialog import MessageTypeDialog
 from urh.controller.dialogs.ProtocolLabelDialog import ProtocolLabelDialog
 from urh.models.LabelValueTableModel import LabelValueTableModel
@@ -83,7 +87,7 @@ class CompareFrameController(QWidget):
         self.assign_message_type_action.setChecked(True)
         self.assign_labels_action = self.analyze_menu.addAction(self.tr("Assign labels"))
         self.assign_labels_action.setCheckable(True)
-        self.assign_labels_action.setChecked(False)
+        self.assign_labels_action.setChecked(True)
         self.assign_participant_address_action = self.analyze_menu.addAction(self.tr("Assign participant addresses"))
         self.assign_participant_address_action.setCheckable(True)
         self.assign_participant_address_action.setChecked(True)
@@ -388,10 +392,13 @@ class CompareFrameController(QWidget):
         update = False
 
         for msg in self.proto_analyzer.messages:
-            i = next((i for i, d in enumerate(self.decodings) if d.name == msg.decoder.name), 0)
-            if msg.decoder != self.decodings[i]:
+            decoder = next((d for d in self.decodings if d.name == msg.decoder.name), None)
+            if decoder is None:
+                continue
+
+            if msg.decoder != decoder:
                 update = True
-                msg.decoder = self.decodings[i]
+                msg.decoder = decoder
                 msg.clear_decoded_bits()
                 msg.clear_encoded_bits()
 
@@ -439,6 +446,15 @@ class CompareFrameController(QWidget):
                         messsage_type.name += " (" + os.path.split(filename)[1].rstrip(".xml").rstrip(".proto") + ")"
                     self.proto_analyzer.message_types.append(messsage_type)
 
+        update_project = False
+        for msg in pa.messages:
+            if msg.participant is not None and msg.participant not in self.project_manager.participants:
+                self.project_manager.participants.append(msg.participant)
+                update_project = True
+
+        if update_project:
+            self.project_manager.project_updated.emit()
+
         self.message_type_table_model.update()
         self.add_protocol(protocol=pa)
 
@@ -945,11 +961,15 @@ class CompareFrameController(QWidget):
 
         view = self.ui.cbProtoView.currentIndex()
         result = []
+        f = 1 if self.ui.cbProtoView.currentIndex() == 0 else 4 if self.ui.cbProtoView.currentIndex() == 1 else 8
         for i in range(row_start, row_end):
             message = self.proto_analyzer.messages[i]
             for label in message.message_type:
+                if label in result:
+                    continue
                 lbl_start, lbl_end = message.get_label_range(lbl=label, view=view, decode=True)
-                if any(j in range(lbl_start, lbl_end) for j in range(col_start, col_end)) and label not in result:
+                a = message.alignment_offset
+                if any(j in range(lbl_start, lbl_end) for j in range(col_start - a//f, col_end - a//f)):
                     result.append(label)
 
         return result
@@ -1006,7 +1026,7 @@ class CompareFrameController(QWidget):
 
         if self.assign_participants_action.isChecked():
             for protocol in self.protocol_list:
-                protocol.auto_assign_participants(self.protocol_model.participants)
+                AutoAssigner.auto_assign_participants(protocol.messages, self.protocol_model.participants)
             self.refresh_assigned_participants_ui()
 
         self.ui.progressBarLogicAnalyzer.setFormat("%p% (Assign message type by rules)")
@@ -1019,16 +1039,20 @@ class CompareFrameController(QWidget):
         self.ui.progressBarLogicAnalyzer.setValue(75)
 
         if self.assign_labels_action.isChecked():
-            self.proto_analyzer.auto_assign_labels()
-            self.protocol_model.update()
-            self.label_value_model.update()
-            self.message_type_table_model.update()
-            self.ui.tblViewMessageTypes.clearSelection()
+            try:
+                self.proto_analyzer.auto_assign_labels()
+                self.protocol_model.update()
+                self.label_value_model.update()
+                self.message_type_table_model.update()
+                self.ui.tblViewMessageTypes.clearSelection()
+            except Exception as e:
+                Errors.exception(e)
 
         self.ui.progressBarLogicAnalyzer.setValue(90)
 
         if self.assign_participant_address_action.isChecked():
-            self.proto_analyzer.auto_assign_participant_addresses(self.protocol_model.participants)
+            AutoAssigner.auto_assign_participant_addresses(self.proto_analyzer.messages,
+                                                           self.protocol_model.participants)
 
         self.ui.progressBarLogicAnalyzer.setValue(100)
         self.unsetCursor()
@@ -1229,7 +1253,7 @@ class CompareFrameController(QWidget):
     @pyqtSlot(int, int, int)
     def on_create_label_triggered(self, msg_index, start, end):
         a = self.protocol_model.get_alignment_offset_at(msg_index)
-        self.add_protocol_label(start=start - a, end=end - a,
+        self.add_protocol_label(start=start - a, end=end - a - 1,
                                 messagenr=msg_index, proto_view=self.ui.cbProtoView.currentIndex())
 
     @pyqtSlot()
@@ -1331,7 +1355,7 @@ class CompareFrameController(QWidget):
         f = 4 if cur_view == 1 else 8 if cur_view == 2 else 1
         start, end = start * f, end * f
 
-        bits = message.decoded_bits_str[start:end]
+        bits = message.decoded_bits_str[start-message.alignment_offset:end-message.alignment_offset]
         hexs = "".join(("{0:x}".format(int(bits[i:i + 4], 2)) for i in range(0, len(bits), 4)))
         decimals = str(int(bits, 2)) if len(bits) > 0 else ""
 
@@ -1358,7 +1382,10 @@ class CompareFrameController(QWidget):
             self.active_group_ids = list(active_group_ids)
             self.active_group_ids.sort()
 
-        self.ui.lblRSSI.setText(locale.format_string("%.2f", message.rssi))
+        if message.rssi > 0:
+            self.ui.lblRSSI.setText(locale.format_string("%.2f dBm", 10*math.log10(message.rssi)))
+        else:
+            self.ui.lblRSSI.setText("-\u221e dBm")
         if isinstance(message.absolute_time, str):
             # For protocol files the abs time is the timestamp as string
             abs_time = message.absolute_time
@@ -1378,7 +1405,7 @@ class CompareFrameController(QWidget):
 
     @pyqtSlot(int)
     def on_ref_index_changed(self, new_ref_index: int):
-        if new_ref_index != -1:
+        if new_ref_index != -1 and self.protocol_model.row_count:
             hide_correction = 0
             for i in range(0, self.protocol_model.row_count):
                 if self.ui.tblViewProtocol.isRowHidden((new_ref_index + i) % self.protocol_model.row_count):
